@@ -26,6 +26,34 @@ class TrtcClient(AbstractClient):
     _service = 'trtc'
 
 
+    def CreatePicture(self, request):
+        """This API is used to upload an image.
+
+        :param request: Request instance for CreatePicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.CreatePictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.CreatePictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreatePicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreatePictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateTroubleInfo(self, request):
         """This API is used to create exception information.
 
@@ -54,6 +82,34 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeletePicture(self, request):
+        """This API is used to delete an image.
+
+        :param request: Request instance for DeletePicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DeletePictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DeletePictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeletePicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeletePictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAbnormalEvent(self, request):
         """This API is used to query exception occurrences under a specified `SDKAppID` and return the exception IDs and possible causes. It queries data in last 15 days, and the query period is up to 1 hour, which can start and end on different days. For more information about exceptions, please see the exception event ID mapping table: https://intl.cloud.tencent.com/document/product/647/37906.
 
@@ -167,6 +223,34 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePicture(self, request):
+        """This API is used to query the parameters of an image.
+
+        :param request: Request instance for DescribePicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribePictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribePictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRealtimeNetwork(self, request):
         """This API is used to query the network conditions of an `SDKAppID`, including upstream and downstream packet loss, in the last 24 hours on a per-minute basis. The query period must be 1-60 minutes.
 
@@ -365,6 +449,34 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyPicture(self, request):
+        """This API is used to modify the parameters of an image.
+
+        :param request: Request instance for ModifyPicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.ModifyPictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.ModifyPictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyPicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyPictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RemoveUser(self, request):
         """This API is used to remove a user from a room. It is applicable to scenarios where the anchor, room owner, or admin wants to kick out a user. It supports all platforms. For Android, iOS, Windows, and macOS, the TRTC SDK needs to be upgraded to v6.6 or above.
 
